@@ -21,5 +21,5 @@ from .src.producer.base import IWorker, IWorkerGroup
 from .src.producer.worker import EmitWorker
 from .src.producer.worker_group import EmitWorkerGroup
 from .src.producer.builder import EmitWorkerBuilder
-from .src.producer.factory import EmitWorkerGroupFactory, EmitWorkerMasterFactory
+from .src.producer.factory import EmitWorkerGroupFactory, EmitWorkerMasterFactory, is_worker, is_group, run
 from .src.producer.decorate import emit_decorate
\ No newline at end of file
