@@ -17,9 +17,9 @@ WrappedReturn = Callable[[Optional[Tuple], Optional[Dict]], EmitWorker]
 
 def _factory(speed: SpeedTypes,
              count: Size = 1,
-             unit: SpeedUnit = UnitOfTime.MILLISECOND,
+             speed_unit: SpeedUnit = UnitOfTime.MILLISECOND,
              thread_workers: int = None):
-    speed = Speed(speed, unit)
+    speed = Speed(speed, speed_unit)
     return partial(
         EmitWorker,
         counter=CountGenerator(speed, count),
@@ -31,12 +31,12 @@ def _factory(speed: SpeedTypes,
 
 def emit_decorate(speed: SpeedTypes,
                   count: Size = 1,
-                  unit: SpeedUnit = UnitOfTime.MILLISECOND,
+                  speed_unit: SpeedUnit = UnitOfTime.MICROSECOND,
                   thread_workers: int = None) -> DecorateReturn:
     def decorator(func: CoroOrFunction) -> WrappedReturn:
         @wraps(func)
         def wrapped(*args, **kwargs) -> EmitWorker:
-            f = _factory(speed, count, unit, thread_workers)
+            f = _factory(speed, count, speed_unit, thread_workers)
             return f(target=func, args=args, kwargs=kwargs)
 
         return wrapped
